Account Limit Rest API — Rucio 1.2 documentation

# Account Limit Rest API

Overview

Resource | Operation | Description
--- | --- | ---
AccountLimit | POST /accounts/(account)/(rse) | Create/update account limits.
| DELETE /accounts/(account)/(rse) | Delete account limits.

Details

`POST` `/accounts/`(account)`/`(rse)

  Create or update an account limit.

  Parameters: | account – Account name. rse – RSE name.
  Status Codes: | 201 Created – Successfully created or updated. 401 Unauthorized – Invalid auth token. 404 Not Found – RSE not found. 404 Not Found – Account not found

`DELETE` `/accounts/`(account)`/`(rse)

  Delete an account limit.

  Parameters: | account – Account name. rse – RSE name.
  Status Codes: | 200 OK – Successfully deleted. 401 Unauthorized – Invalid auth token. 404 Not Found – RSE not found. 404 Not Found – Account not found